@@ -214,7 +214,9 @@ class Yhat(API):
             same data, but compatible with JSON
         """
         if isinstance(data, pd.DataFrame):
-            data = json.loads(data.to_json())
+            # Typecasting ensures proper jsonification
+            data = data.astype(object)
+            data = data.to_dict('list')
         return data
 
     def predict(self, model, data):
@@ -329,7 +331,7 @@ need to connect to the server first. try running "connect_to_socket"
         # this makes it a lot easier to upgrade the client
         import yhat
         bundle["reqs"] += '\n' + "yhat==" + yhat.__version__
-        bundle["reqs"] = bundle["reqs"].strip()
+        bundle["reqs"] = bundle["reqs"].strip().replace('"', '').replace("'", "")
         return bundle
     
     def deploy(self, name, model, session, sure=False):
